@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package IPC::Lockfile;
-$IPC::Lockfile::VERSION = '0.04';
+$IPC::Lockfile::VERSION = '0.05';
 # ABSTRACT: run only one instance of a program at a time using flock
 use Fcntl qw(:flock);
 
@@ -24,7 +24,7 @@ IPC::Lockfile - run only one instance of a program at a time using flock
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -46,6 +46,10 @@ run on an OS that supports C<flock> (e.g. Linux, BSD, OSX and Windows).
 
 =head1 SEE ALSO
 
+L<Sys::RunAlone> for a more flexible module that uses the same technique as C<IPC::Lockfile>
+
+My PerlTricks.com L<article|http://perltricks.com/article/2/2015/11/4/Run-only-one-instance-of-a-program-at-a-time> about this solution.
+
 L<IPC::Pidfile> for a PID-based solution that relies on signals and has a race
 condition (not recommended).
 
